@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2018 Firejail Authors
+ * Copyright (C) 2014-2019 Firejail Authors
  *
  * This file is part of firejail project
  *
@@ -241,6 +241,9 @@ error:
 // return 1 if the command is to be added to the linked list of profile commands
 // return 0 if the command was already executed inside the function
 int profile_check_line(char *ptr, int lineno, const char *fname) {
+#ifdef HAVE_WHITELIST
+	static int whitelist_warning_printed = 0;
+#endif
 	EUID_ASSERT();
 
 	// check and process conditional profile lines
@@ -868,7 +871,7 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 	}
 
 	// nice value
-	if (strncmp(ptr, "nice ", 4) == 0) {
+	if (strncmp(ptr, "nice ", 5) == 0) {
 		cfg.nice = atoi(ptr + 5);
 		if (getuid() != 0 &&cfg.nice < 0)
 			cfg.nice = 0;
@@ -878,7 +881,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 
 	// cgroup
 	if (strncmp(ptr, "cgroup ", 7) == 0) {
-		set_cgroup(ptr + 7);
+		if (checkcfg(CFG_CGROUP))
+			set_cgroup(ptr + 7);
+		else
+			warning_feature_disabled("cgroup");
 		return 0;
 	}
 
@@ -1123,8 +1129,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 			}
 			cfg.overlay_dir = fs_check_overlay_dir(subdirname, arg_overlay_reuse);
 		}
-
+		else
+			warning_feature_disabled("overlayfs");
 		return 0;
+
 	} else if (strcmp(ptr, "overlay-tmpfs") == 0) {
 		if (checkcfg(CFG_OVERLAYFS)) {
 			if (arg_overlay) {
@@ -1141,9 +1149,11 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 				exit(1);
 			}
 			arg_overlay = 1;
-
-			return 0;
 		}
+		else
+			warning_feature_disabled("overlayfs");
+		return 0;
+
 	} else if (strcmp(ptr, "overlay") == 0) {
 		if (checkcfg(CFG_OVERLAYFS)) {
 			if (arg_overlay) {
@@ -1168,9 +1178,10 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 			cfg.overlay_dir = fs_check_overlay_dir(subdirname, arg_overlay_reuse);
 
 			free(subdirname);
-
-			return 0;
 		}
+		else
+			warning_feature_disabled("overlayfs");
+		return 0;
 	}
 #endif
 
@@ -1257,26 +1268,30 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 	}
 
 	if (strncmp(ptr, "join-or-start ", 14) == 0) {
-		// try to join by name only
-		pid_t pid;
-		if (!name2pid(ptr + 14, &pid)) {
-			if (!cfg.shell && !arg_shell_none)
-				cfg.shell = guess_shell();
+		if (checkcfg(CFG_JOIN) || getuid() == 0) {
+			// try to join by name only
+			pid_t pid;
+			if (!name2pid(ptr + 14, &pid)) {
+				if (!cfg.shell && !arg_shell_none)
+					cfg.shell = guess_shell();
 
-			// find first non-option arg
-			int i;
-			for (i = 1; i < cfg.original_argc && strncmp(cfg.original_argv[i], "--", 2) != 0; i++);
+				// find first non-option arg
+				int i;
+				for (i = 1; i < cfg.original_argc && strncmp(cfg.original_argv[i], "--", 2) != 0; i++);
 
-			join(pid, cfg.original_argc,cfg.original_argv, i + 1);
-			exit(0);
-		}
+				join(pid, cfg.original_argc,cfg.original_argv, i + 1);
+				exit(0);
+			}
 
-		// set sandbox name and start normally
-		cfg.name = ptr + 14;
-		if (strlen(cfg.name) == 0) {
-			fprintf(stderr, "Error: invalid sandbox name\n");
-			exit(1);
+			// set sandbox name and start normally
+			cfg.name = ptr + 14;
+			if (strlen(cfg.name) == 0) {
+				fprintf(stderr, "Error: invalid sandbox name\n");
+				exit(1);
+			}
 		}
+		else
+			warning_feature_disabled("join");
 		return 0;
 	}
 
@@ -1298,8 +1313,13 @@ int profile_check_line(char *ptr, int lineno, const char *fname) {
 			arg_whitelist = 1;
 			ptr += 10;
 		}
-		else
+		else {
+			if (!whitelist_warning_printed) {
+				warning_feature_disabled("whitelist");
+				whitelist_warning_printed = 1;
+			}
 			return 0;
+		}
 #else
 		return 0;
 #endif
